==> shapeshifter_uftp-1.3.0.tar.gz: shapeshifter_uftp-1.3.0/shapeshifter_uftp/uftp/__init__.py <==
from .agr_cro import (
    AgrPortfolioQuery,
    AgrPortfolioQueryResponse,
    AgrPortfolioQueryResponseCongestionPoint,
    AgrPortfolioQueryResponseConnection,
    AgrPortfolioQueryResponseDSOPortfolio,
    AgrPortfolioQueryResponseDSOView,
    AgrPortfolioUpdate,
    AgrPortfolioUpdateConnection,
    AgrPortfolioUpdateResponse,
)
from .agr_dso import (
    ContractSettlement,
    ContractSettlementISP,
    ContractSettlementPeriod,
    DPrognosis,
    DPrognosisISP,
    DPrognosisResponse,
    FlexMessage,
    FlexOffer,
    FlexOfferOption,
    FlexOfferOptionISP,
    FlexOfferResponse,
    FlexOfferRevocation,
    FlexOfferRevocationResponse,
    FlexOrder,
    FlexOrderISP,
    FlexOrderResponse,
    FlexOrderSettlement,
    FlexOrderSettlementISP,
    FlexOrderSettlementStatus,
    FlexOrderStatus,
    FlexRequest,
    FlexRequestISP,
    FlexRequestResponse,
    FlexReservationUpdate,
    FlexReservationUpdateISP,
    FlexReservationUpdateResponse,
    FlexSettlement,
    FlexSettlementResponse,
)
from .common import (
    AcceptedDisputed,
    AcceptedRejected,
    AvailableRequested,
    PayloadMessage,
    PayloadMessageResponse,
    RedispatchBy,
    SignedMessage,
    TestMessage,
    TestMessageResponse,
    UsefRole,
)
from .cro_dso import (
    DsoPortfolioQuery,
    DsoPortfolioQueryCongestionPoint,
    DsoPortfolioQueryConnection,
    DsoPortfolioQueryResponse,
    DsoPortfolioUpdate,
    DsoPortfolioUpdateCongestionPoint,
    DsoPortfolioUpdateConnection,
    DsoPortfolioUpdateResponse,
)
from .metering import (
    Metering,
    MeteringISP,
    MeteringProfile,
    MeteringProfileEnum,
    MeteringResponse,
    MeteringUnit,
)

ACCEPTED = AcceptedRejected.ACCEPTED
REJECTED = AcceptedRejected.REJECTED

__all__ = [
    "AcceptedRejected",
    "AcceptedDisputed",
    "AvailableRequested",
    "AgrPortfolioQuery",
    "AgrPortfolioQueryResponse",
    "AgrPortfolioQueryResponseCongestionPoint",
    "AgrPortfolioQueryResponseConnection",
    "AgrPortfolioQueryResponseDSOPortfolio",
    "AgrPortfolioQueryResponseDSOView",
    "AgrPortfolioUpdate",
    "AgrPortfolioUpdateConnection",
    "AgrPortfolioUpdateResponse",
    "ContractSettlement",
    "ContractSettlementISP",
    "ContractSettlementPeriod",
    "DPrognosis",
    "DPrognosisISP",
    "DPrognosisResponse",
    "DsoPortfolioQuery",
    "DsoPortfolioQueryCongestionPoint",
    "DsoPortfolioQueryConnection",
    "DsoPortfolioQueryResponse",
    "DsoPortfolioUpdate",
    "DsoPortfolioUpdateCongestionPoint",
    "DsoPortfolioUpdateConnection",
    "DsoPortfolioUpdateResponse",
    "FlexMessage",
    "FlexOffer",
    "FlexOfferOption",
    "FlexOfferOptionISP",
    "FlexOfferResponse",
    "FlexOfferRevocation",
    "FlexOfferRevocationResponse",
    "FlexOrder",
    "FlexOrderISP",
    "FlexOrderResponse",
    "FlexOrderSettlement",
    "FlexOrderSettlementISP",
    "FlexOrderSettlementStatus",
    "FlexOrderStatus",
    "FlexRequest",
    "FlexRequestISP",
    "FlexRequestResponse",
    "FlexReservationUpdate",
    "FlexReservationUpdateISP",
    "FlexReservationUpdateResponse",
    "FlexSettlement",
    "FlexSettlementResponse",
    "Metering",
    "MeteringISP",
    "MeteringProfile",
    "MeteringProfileEnum",
    "MeteringResponse",
    "MeteringUnit",
    "PayloadMessage",
    "PayloadMessageResponse",
    "SignedMessage",
    "TestMessage",
    "TestMessageResponse",
    "UsefRole",
    "RedispatchBy",
]

routing_map = {
    AgrPortfolioQuery: ("AGR", "CRO"),
    AgrPortfolioQueryResponse: ("CRO", "AGR"),
    AgrPortfolioUpdate: ("AGR", "CRO"),
    AgrPortfolioUpdateResponse: ("CRO", "AGR"),
    DPrognosis: ("AGR", "DSO"),
    DPrognosisResponse: ("DSO", "AGR"),
    DsoPortfolioQuery: ("DSO", "CRO"),
    DsoPortfolioQueryResponse: ("CRO", "DSO"),
    DsoPortfolioUpdate: ("DSO", "CRO"),
    DsoPortfolioUpdateResponse: ("CRO", "DSO"),
    FlexOffer: ("AGR", "DSO"),
    FlexOfferResponse: ("DSO", "AGR"),
    FlexOfferRevocation: ("AGR", "DSO"),
    FlexOfferRevocationResponse: ("DSO", "AGR"),
    FlexOrder: ("DSO", "AGR"),
    FlexOrderResponse: ("AGR", "DSO"),
    FlexRequest: ("DSO", "AGR"),
    FlexRequestResponse: ("AGR", "DSO"),
    FlexReservationUpdate: ("DSO", "AGR"),
    FlexReservationUpdateResponse: ("AGR", "DSO"),
    FlexSettlement: ("DSO", "AGR"),
    FlexSettlementResponse: ("AGR", "DSO"),
    Metering: ("AGR", "DSO"),
    MeteringResponse: ("DSO", "AGR"),

}

origin_map = {key: origin for key, (origin, destination) in routing_map.items()}
destination_map = {key: destination for key, (origin, destination) in routing_map.items()}

==> shapeshifter_uftp-2.0.0b2.tar.gz: shapeshifter_uftp-2.0.0b2/shapeshifter_uftp/uftp/__init__.py <==
from .enums import *
from .messages import *

ACCEPTED = AcceptedRejected.ACCEPTED
REJECTED = AcceptedRejected.REJECTED

__all__ = [
    "AcceptedRejected",
    "AcceptedDisputed",
    "AvailableRequested",
    "AgrPortfolioQuery",
    "AgrPortfolioQueryResponse",
    "AgrPortfolioQueryResponseCongestionPoint",
    "AgrPortfolioQueryResponseConnection",
    "AgrPortfolioQueryResponseDSOPortfolio",
    "AgrPortfolioQueryResponseDSOView",
    "AgrPortfolioUpdate",
    "AgrPortfolioUpdateConnection",
    "AgrPortfolioUpdateResponse",
    "ContractSettlement",
    "ContractSettlementISP",
    "ContractSettlementPeriod",
    "DPrognosis",
    "DPrognosisISP",
    "DPrognosisResponse",
    "DsoPortfolioQuery",
    "DsoPortfolioQueryCongestionPoint",
    "DsoPortfolioQueryConnection",
    "DsoPortfolioQueryResponse",
    "DsoPortfolioUpdate",
    "DsoPortfolioUpdateCongestionPoint",
    "DsoPortfolioUpdateConnection",
    "DsoPortfolioUpdateResponse",
    "FlexMessage",
    "FlexOffer",
    "FlexOfferOption",
    "FlexOfferOptionISP",
    "FlexOfferResponse",
    "FlexOfferRevocation",
    "FlexOfferRevocationResponse",
    "FlexOrder",
    "FlexOrderISP",
    "FlexOrderResponse",
    "FlexOrderSettlement",
    "FlexOrderSettlementISP",
    "FlexOrderSettlementStatus",
    "FlexOrderStatus",
    "FlexRequest",
    "FlexRequestISP",
    "FlexRequestResponse",
    "FlexReservationUpdate",
    "FlexReservationUpdateISP",
    "FlexReservationUpdateResponse",
    "FlexSettlement",
    "FlexSettlementResponse",
    "Metering",
    "MeteringISP",
    "MeteringProfile",
    "MeteringProfileEnum",
    "MeteringResponse",
    "MeteringUnit",
    "PayloadMessage",
    "PayloadMessageResponse",
    "SignedMessage",
    "TestMessage",
    "TestMessageResponse",
    "UsefRole",
    "RedispatchBy",
]

routing_map = {
    AgrPortfolioQuery: ("AGR", "CRO"),
    AgrPortfolioQueryResponse: ("CRO", "AGR"),
    AgrPortfolioUpdate: ("AGR", "CRO"),
    AgrPortfolioUpdateResponse: ("CRO", "AGR"),
    DPrognosis: ("AGR", "DSO"),
    DPrognosisResponse: ("DSO", "AGR"),
    DsoPortfolioQuery: ("DSO", "CRO"),
    DsoPortfolioQueryResponse: ("CRO", "DSO"),
    DsoPortfolioUpdate: ("DSO", "CRO"),
    DsoPortfolioUpdateResponse: ("CRO", "DSO"),
    FlexOffer: ("AGR", "DSO"),
    FlexOfferResponse: ("DSO", "AGR"),
    FlexOfferRevocation: ("AGR", "DSO"),
    FlexOfferRevocationResponse: ("DSO", "AGR"),
    FlexOrder: ("DSO", "AGR"),
    FlexOrderResponse: ("AGR", "DSO"),
    FlexRequest: ("DSO", "AGR"),
    FlexRequestResponse: ("AGR", "DSO"),
    FlexReservationUpdate: ("DSO", "AGR"),
    FlexReservationUpdateResponse: ("AGR", "DSO"),
    FlexSettlement: ("DSO", "AGR"),
    FlexSettlementResponse: ("AGR", "DSO"),
    Metering: ("AGR", "DSO"),
    MeteringResponse: ("DSO", "AGR"),
}

request_response_map = {
    AgrPortfolioQuery: AgrPortfolioQueryResponse,
    AgrPortfolioUpdate: AgrPortfolioUpdateResponse,
    DPrognosis: DPrognosisResponse,
    DsoPortfolioQuery: DsoPortfolioQueryResponse,
    DsoPortfolioUpdate: DsoPortfolioUpdateResponse,
    FlexOffer: FlexOfferResponse,
    FlexOfferRevocation: FlexOfferRevocationResponse,
    FlexOrder: FlexOrderResponse,
    FlexRequest: FlexRequestResponse,
    FlexReservationUpdate: FlexReservationUpdateResponse,
    FlexSettlement: FlexSettlementResponse,
    Metering: MeteringResponse,
    TestMessage: TestMessageResponse,
}

origin_map = {key: origin for key, (origin, destination) in routing_map.items()}
destination_map = {key: destination for key, (origin, destination) in routing_map.items()}
